/* ActiveWhen.java

        Purpose:
                
        Description:
                
        History:
                Mon Oct 16 14:40:39 CST 2023, Created by jamson

Copyright (C) 2023 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Define a condition for when a track should be active and not.
 * <p>Can either be a function callback or a configuration object.
 * <p>If a function is used, it should return a boolean for whether or not the track should be active.
 * The function is called for each audio event, and receives a parameter object with time,
 * and potentially point and value properties depending on the track.
 * point is available if the audio event is related to a data point.
 * value is available if the track is used as a context track, and valueInterval is used.
 * @author Jamson Chan
 * @since 11.2.0.0
 */
public class ActiveWhen extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		crossingDown,
		crossingUp,
		max,
		min,
		prop,
	}

	/**
	 * Returns track is only active when prop was above, and is now at or below this value.
	 * <p>If both crossingUp and crossingDown are defined, the track is active if either condition is met.
	 * <p>
	 * Default: null
	 */
	public Number getCrossingDown() {
		return getAttr(Attrs.crossingDown, null).asNumber();
	}

	/**
	 * Sets track is only active when prop was above, and is now at or below this value.
	 * <p>If both crossingUp and crossingDown are defined, the track is active if either condition is met.
	 */
	public void setCrossingDown(Number crossingDown) {
		setAttr(Attrs.crossingDown, crossingDown);
	}

	/**
	 * Returns track is only active when prop was below, and is now at or above this value.
	 * <p>If both crossingUp and crossingDown are defined, the track is active if either condition is met.
	 * <p>
	 * Default: null
	 */
	public Number getCrossingUp() {
		return getAttr(Attrs.crossingUp, null).asNumber();
	}

	/**
	 * Sets track is only active when prop was below, and is now at or above this value.
	 * <p>If both crossingUp and crossingDown are defined, the track is active if either condition is met.
	 */
	public void setCrossingUp(Number crossingUp) {
		setAttr(Attrs.crossingUp, crossingUp);
	}

	/**
	 * Returns track is only active when prop is below or at this value.
	 * <p>
	 * Default: null
	 */
	public Number getMax() {
		return getAttr(Attrs.max, null).asNumber();
	}

	/**
	 * Sets track is only active when prop is below or at this value.
	 */
	public void setMax(Number max) {
		setAttr(Attrs.max, max);
	}

	/**
	 * Returns track is only active when prop is above or at this value.
	 * <p>
	 * Default: null
	 */
	public Number getMin() {
		return getAttr(Attrs.min, null).asNumber();
	}

	/**
	 * Sets track is only active when prop is above or at this value.
	 */
	public void setMin(Number min) {
		setAttr(Attrs.min, min);
	}

	/**
	 * Returns the point property to compare, for example y or x.
	 * <p>
	 * Default: null
	 */
	public String getProp() {
		return getAttr(Attrs.prop, null).asString();
	}

	/**
	 * Sets the point property to compare, for example y or x.
	 */
	public void setProp(String prop) {
		setAttr(Attrs.prop, prop);
	}
}
