/* FocusBorder.java

	Purpose:
		
	Description:
		
	History:
		12:11 PM 2022/9/19, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import java.util.LinkedHashMap;
import java.util.Map;

import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.chart.util.MapsHelper;
import org.zkoss.lang.Generics;

/**
 * Options for the focus border drawn around elements while navigating through them.
 * @author jumperchen
 */
public class FocusBorder extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		enabled,
		hideBrowserFocusOutline,
		margin,
		style
	}

	/**
	 * Returns whether to enable/disable focus border for chart.
	 * <p> Default: {@code true}
	 */
	public boolean isEnabled() {
		return getAttr(Attrs.enabled, true).asBoolean();
	}

	/**
	 * Sets whether to enable/disable focus border for chart.
	 * <p> Default: {@code true}
	 */
	public void setEnabled(boolean enabled) {
		setAttr(Attrs.enabled, enabled);
	}

	/**
	 * Returns whether to hide the browser's default focus indicator.
	 * <p>Default: {@code true}
	 */
	public boolean isHideBrowserFocusOutline() {
		return getAttr(Attrs.hideBrowserFocusOutline, true).asBoolean();
	}

	/**
	 * Sets whether to hide the browser's default focus indicator.
	 * <p>Default: {@code true}
	 */
	public void setHideBrowserFocusOutline(boolean hideBrowserFocusOutline) {
		setAttr(Attrs.hideBrowserFocusOutline, hideBrowserFocusOutline);
	}

	/**
	 * Returns the focus border margin around the elements.
	 * <p>Default: {@code 2}
	 */
	public Number getMargin() {
		return getAttr(Attrs.margin, 2).asNumber();
	}

	/**
	 * Sets the focus border margin around the elements.
	 * <p>Default: {@code 2}
	 */
	public void setMargin(Number margin) {
		setAttr(Attrs.margin, margin);
	}

	/**
	 * Returns the style options for the focus border drawn around elements while
	 * navigating through them.
	 * <p>Note that some browsers in addition draw their own borders for focused elements.
	 * These automatic borders cannot be styled by Highcharts.
	 * <p>Default: null
	 */
	public <K, V> Map<K, V> getStyle() {
		return Generics.cast(getAttr(Attrs.style));
	}

	/**
	 * Sets the style options for the focus border drawn around elements while
	 * navigating through them.
	 * <p>Note that some browsers in addition draw their own borders for focused elements.
	 * These automatic borders cannot be styled by Highcharts.
	 * <p>Default: null
	 */
	public void setStyle(String style) {
		setStyle(MapsHelper.parse(new LinkedHashMap<>(), style, ':', ';', '\''));
	}

	/**
	 * Sets the style options for the focus border drawn around elements while
	 * navigating through them.
	 * <p>Note that some browsers in addition draw their own borders for focused elements.
	 * These automatic borders cannot be styled by Highcharts.
	 * <p>Default: null
	 */
	public <K, V> void setStyle(Map<K, V> style) {
		setAttr(Attrs.style, style);
	}
}