/* Frequency.java

        Purpose:
                
        Description:
                
        History:
                Mon Oct 16 14:09:55 CST 2023, Created by jamson

Copyright (C) 2023 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Frequency in Hertz of notes. Overrides pitch mapping if set.
 * @author Jamson Chan
 * @since 11.2.0.0
 */
public class Frequency extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		mapFunction,
		mapTo,
		max,
		min,
		value,
		within
	}

	/**
	 * Returns how to perform the mapping. ("linear", "logarithmic")
	 * <p>
	 * Default: null
	 */
	public String getMapFunction() {
		return getAttr(Attrs.mapFunction, null).asString();
	}

	/**
	 * Sets how to perform the mapping. ("linear", "logarithmic")
	 */
	public void setMapFunction(String mapFunction) {
		setAttr(Attrs.mapFunction, mapFunction);
	}

	/**
	 * Returns a point property to map the mapping parameter to.
	 * <p>A negative sign - can be placed before the property name to make mapping inverted.
	 * <p>
	 * Default: null
	 */
	public String getMapTo() {
		return getAttr(Attrs.mapTo, null).asString();
	}

	/**
	 * Sets a point property to map the mapping parameter to.
	 * <p>A negative sign - can be placed before the property name to make mapping inverted.
	 */
	public void setMapTo(String mapTo) {
		setAttr(Attrs.mapTo, mapTo);
	}

	/**
	 * Returns the maximum value for the audio parameter. This is the highest value the audio parameter will be mapped to.
	 * <p>
	 * Default: null
	 */
	public Number getMax() {
		return getAttr(Attrs.max, null).asNumber();
	}

	/**
	 * Sets the maximum value for the audio parameter. This is the highest value the audio parameter will be mapped to.
	 */
	public void setMax(Number max) {
		setAttr(Attrs.max, max);
	}

	/**
	 * Returns the minimum value for the audio parameter. This is the lowest value the audio parameter will be mapped to.
	 * <p>
	 * Default: null
	 */
	public Number getMin() {
		return getAttr(Attrs.min, null).asNumber();
	}

	/**
	 * Sets the minimum value for the audio parameter. This is the lowest value the audio parameter will be mapped to.
	 */
	public void setMin(Number min) {
		setAttr(Attrs.min, min);
	}

	/**
	 * Returns a fixed value to use for the prop when mapping.
	 * <p>For example, if mapping to y, setting value to 4 will map as if all points had a y value of 4.
	 * <p>
	 * Default: null
	 */
	public Number getValue() {
		return getAttr(Attrs.value, null).asNumber();
	}

	/**
	 * Sets a fixed value to use for the prop when mapping.
	 * <p>For example, if mapping to y, setting value to 4 will map as if all points had a y value of 4.
	 */
	public void setValue(Number value) {
		setAttr(Attrs.value, value);
	}

	/**
	 * Returns what data values to map the parameter within. ("chart", "series", "xAxis", "yAxis")
	 * <p>Mapping within "series" will make the lowest value point in the series map to the min audio parameter value, and the highest value will map to the max audio parameter.
	 * <p>Mapping within "chart" will make the lowest value point in the whole chart map to the min audio parameter value, and the highest value in the whole chart will map to the max audio parameter.
	 * <p>You can also map within the X or Y axis of each series.
	 * <p>
	 * Default: null
	 */
	public String getWithin() {
		return getAttr(Attrs.within, null).asString();
	}

	/**
	 * Sets what data values to map the parameter within. ("chart", "series", "xAxis", "yAxis")
	 * <p>Mapping within "series" will make the lowest value point in the series map to the min audio parameter value, and the highest value will map to the max audio parameter.
	 * <p>Mapping within "chart" will make the lowest value point in the whole chart map to the min audio parameter value, and the highest value in the whole chart will map to the max audio parameter.
	 * <p>You can also map within the X or Y axis of each series.
	 */
	public void setWithin(String within) {
		setAttr(Attrs.within, within);
	}
}
