/* GlobalContextTrack.java

        Purpose:
                
        Description:
                
        History:
                Fri Sep 15 14:40:55 CST 2023, Created by jamson

Copyright (C) 2023 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Context tracks to add globally, an array of either instrument tracks, speech tracks, or a mix.
 * <p>Context tracks are not tied to data points, but play at a set interval - either based on time or on prop values.
 * @author Jamson Chan
 * @since 11.2.0.0
 */
public class GlobalContextTrack extends GlobalTrack {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		timeInterval,
		valueInterval,
		valueMapFunction,
		valueProp
	}

	/**
	 * Returns a context track to play periodically every timeInterval milliseconds while the sonification is playing.
	 * <p>Default: {@code null}
	 */
	public Number getTimeInterval() {
		return getAttr(Attrs.timeInterval, null).asNumber();
	}

	/**
	 * Sets a context track to play periodically every timeInterval milliseconds while the sonification is playing.
	 */
	public void setTimeInterval(Number timeInterval) {
		setAttr(Attrs.timeInterval, timeInterval, null);
	}

	/**
	 * Returns a context track to play periodically every valueInterval units of a data property valueProp while the sonification is playing.
	 * <p>For example, setting valueProp to x and valueInterval to 5 will play the context track for every 5th X value.
	 * <p>The context audio events will be mapped to time according to the prop value relative to the min/max values for that prop.
	 * <p>Default: {@code null}
	 */
	public Number getValueInterval() {
		return getAttr(Attrs.valueInterval, null).asNumber();
	}

	/**
	 * Sets a context track to play periodically every valueInterval units of a data property valueProp while the sonification is playing.
	 * <p>For example, setting valueProp to x and valueInterval to 5 will play the context track for every 5th X value.
	 * <p>The context audio events will be mapped to time according to the prop value relative to the min/max values for that prop.
	 */
	public void setValueInterval(Number valueInterval) {
		setAttr(Attrs.valueInterval, valueInterval, null);
	}

	/**
	 * Returns how to map context events to time when using the <code>valueInterval</code> option.
	 * <p>Default: {@code "linear"}
	 */
	public String getValueMapFunction() {
		return getAttr(Attrs.valueMapFunction, "linear").asString();
	}

	/**
	 * Sets how to map context events to time when using the <code>valueInterval</code> option.
	 */
	public void setValueMapFunction(String valueMapFunction) {
		setAttr(Attrs.valueMapFunction, valueMapFunction, "linear");
	}

	/**
	 * Returns the point property to play context for when using <code>valueInterval</code>.
	 * <p>Default: {@code "x"}
	 */
	public String getValueProp() {
		return getAttr(Attrs.valueProp, "x").asString();
	}

	/**
	 * Sets the point property to play context for when using <code>valueInterval</code>.
	 */
	public void setValueProp(String valueProp) {
		setAttr(Attrs.valueProp, valueProp, "x");
	}

}
