/* LangSeriesSummary.java

	Purpose:
		
	Description:
		
	History:
		11:47 AM 2022/9/20, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Lang configuration for the series main summary. Each series type has two modes:
 *
 * <ol><li>
 * This series type is the only series type used in the chart
 *</li><li>
 * This is a combination chart with multiple series types
 * </li>
 *</ol>
 * <p>
 * If a definition does not exist for the specific series type and mode, the 'default' lang definitions are used.
 *
 * <p>
 * Chart and its subproperties can be accessed with the {@code {chart}} variable.
 * The series and its subproperties can be accessed with the {@code {series}} variable.
 * <p>
 * The series index (starting from 1) can be accessed with the {@code {seriesNumber}} variable.
 *
 * @author jumperchen
 * @since 10.2.1.0
 */
public class LangSeriesSummary extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		bar,
		barCombination,
		boxplot,
		boxplotCombination,
		bubble,
		bubbleCombination,
		column,
		columnCombination,
		_default,
		defaultCombination,
		line,
		lineCombination,
		map,
		mapbubble,
		mapbubbleCombination,
		mapCombination,
		mapline,
		maplineCombination,
		pie,
		pieCombination,
		scatter,
		scatterCombination,
		spline,
		splineCombination
	}

	/**
	 * <p>Default: {@code "{series.name}, bar series {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, bars, bar)}."}
	 */
	public String getBar() {
		return getAttr(Attrs.bar,
				"{series.name}, bar series {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, bars, bar)}.").asString();
	}

	public void setBar(String bar) {
		setAttr(Attrs.bar, bar);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Bar series with {series.points.length} {#plural(series.points.length, bars, bar)}."}
	 */
	public String getBarCombination() {
		return getAttr(Attrs.barCombination,
				"{series.name}, series {seriesNumber} of {chart.series.length}. Bar series with {series.points.length} {#plural(series.points.length, bars, bar)}.").asString();
	}

	public void setBarCombination(String barCombination) {
		setAttr(Attrs.barCombination, barCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, boxplot {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, boxes, box)}."}
	 */
	public String getBoxplot() {
		return getAttr(Attrs.boxplot,
				"{series.name}, boxplot {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, boxes, box)}.").asString();
	}

	public void setBoxplot(String boxplot) {
		setAttr(Attrs.boxplot, boxplot);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Boxplot with {series.points.length} {#plural(series.points.length, boxes, box)}.."}
	 */
	public String getBoxplotCombination() {
		return getAttr(Attrs.boxplotCombination,
				"{series.name}, series {seriesNumber} of {chart.series.length}. Boxplot with {series.points.length} {#plural(series.points.length, boxes, box)}..").asString();
	}

	public void setBoxplotCombination(String boxplotCombination) {
		setAttr(Attrs.boxplotCombination, boxplotCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, bubble series {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, bubbles, bubble)}."}
	 */
	public String getBubble() {
		return getAttr(Attrs.bubble,
				"{series.name}, bubble series {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, bubbles, bubble)}.").asString();
	}

	public void setBubble(String bubble) {
		setAttr(Attrs.bubble, bubble);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Bubble series with {series.points.length} {#plural(series.points.length, bubbles, bubble)}."}
	 */
	public String getBubbleCombination() {
		return getAttr(Attrs.bubbleCombination,
				"{series.name}, series {seriesNumber} of {chart.series.length}. Bubble series with {series.points.length} {#plural(series.points.length, bubbles, bubble)}.").asString();
	}

	public void setBubbleCombination(String bubbleCombination) {
		setAttr(Attrs.bubbleCombination, bubbleCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, bar series {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, bars, bar)}."}
	 */
	public String getColumn() {
		return getAttr(Attrs.column,
				"{series.name}, bar series {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, bars, bar)}.").asString();
	}

	public void setColumn(String column) {
		setAttr(Attrs.column, column);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Bar series with {series.points.length} {#plural(series.points.length, bars, bar)}."}
	 */
	public String getColumnCombination() {
		return getAttr(Attrs.columnCombination,
				"{series.name}, series {seriesNumber} of {chart.series.length}. Bar series with {series.points.length} {#plural(series.points.length, bars, bar)}.").asString();
	}

	public void setColumnCombination(String columnCombination) {
		setAttr(Attrs.columnCombination, columnCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}."}
	 */
	public String getDefault() {
		return getAttr(Attrs._default, "{series.name}, series {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}.").asString();
	}

	public void setDefault(String _default) {
		setAttr(Attrs._default, _default);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}."}
	 */
	public String getDefaultCombination() {
		return getAttr(Attrs.defaultCombination,
				"{series.name}, series {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}.").asString();
	}

	public void setDefaultCombination(String defaultCombination) {
		setAttr(Attrs.defaultCombination, defaultCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, line {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}."}
	 */
	public String getLine() {
		return getAttr(Attrs.line,
				"{series.name}, line {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}.").asString();
	}

	public void setLine(String line) {
		setAttr(Attrs.line, line);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Line with {series.points.length} data {#plural(series.points.length, points, point)}."}
	 */
	public String getLineCombination() {
		return getAttr(Attrs.lineCombination,
				"{series.name}, series {seriesNumber} of {chart.series.length}. Line with {series.points.length} data {#plural(series.points.length, points, point)}.").asString();
	}

	public void setLineCombination(String lineCombination) {
		setAttr(Attrs.lineCombination, lineCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, map {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, areas, area)}."}
	 */
	public String getMap() {
		return getAttr(Attrs.map, "{series.name}, map {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, areas, area)}.").asString();
	}

	public void setMap(String map) {
		setAttr(Attrs.map, map);
	}

	/**
	 * <p>Default: {@code "{series.name}, bubble series {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, bubbles, bubble)}."}
	 */
	public String getMapbubble() {
		return getAttr(Attrs.mapbubble, "{series.name}, bubble series {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, bubbles, bubble)}.").asString();
	}

	public void setMapbubble(String mapbubble) {
		setAttr(Attrs.mapbubble, mapbubble);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Bubble series with {series.points.length} {#plural(series.points.length, bubbles, bubble)}."}
	 */
	public String getMapbubbleCombination() {
		return getAttr(Attrs.mapbubbleCombination, "{series.name}, series {seriesNumber} of {chart.series.length}. Bubble series with {series.points.length} {#plural(series.points.length, bubbles, bubble)}.").asString();
	}

	public void setMapbubbleCombination(String mapbubbleCombination) {
		setAttr(Attrs.mapbubbleCombination, mapbubbleCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Map with {series.points.length} {#plural(series.points.length, areas, area)}."}
	 */
	public String getMapCombination() {
		return getAttr(Attrs.mapCombination, "{series.name}, series {seriesNumber} of {chart.series.length}. Map with {series.points.length} {#plural(series.points.length, areas, area)}.").asString();
	}

	public void setMapCombination(String mapCombination) {
		setAttr(Attrs.mapCombination, mapCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, line {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}."}
	 */
	public String getMapline() {
		return getAttr(Attrs.mapline, "{series.name}, line {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}.").asString();
	}

	public void setMapline(String mapline) {
		setAttr(Attrs.mapline, mapline);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Line with {series.points.length} data {#plural(series.points.length, points, point)}."}
	 */
	public String getMaplineCombination() {
		return getAttr(Attrs.maplineCombination, "{series.name}, series {seriesNumber} of {chart.series.length}. Line with {series.points.length} data {#plural(series.points.length, points, point)}.").asString();
	}

	public void setMaplineCombination(String maplineCombination) {
		setAttr(Attrs.maplineCombination, maplineCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, pie {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, slices, slice)}."}
	 */
	public String getPie() {
		return getAttr(Attrs.pie, "{series.name}, pie {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, slices, slice)}.").asString();
	}

	public void setPie(String pie) {
		setAttr(Attrs.pie, pie);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Pie with {series.points.length} {#plural(series.points.length, slices, slice)}."}
	 */
	public String getPieCombination() {
		return getAttr(Attrs.pieCombination, "{series.name}, series {seriesNumber} of {chart.series.length}. Pie with {series.points.length} {#plural(series.points.length, slices, slice)}.").asString();
	}

	public void setPieCombination(String pieCombination) {
		setAttr(Attrs.pieCombination, pieCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, scatter plot {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, points, point)}."}
	 */
	public String getScatter() {
		return getAttr(Attrs.scatter, "{series.name}, scatter plot {seriesNumber} of {chart.series.length} with {series.points.length} {#plural(series.points.length, points, point)}.").asString();
	}

	public void setScatter(String scatter) {
		setAttr(Attrs.scatter, scatter);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}, scatter plot with {series.points.length} {#plural(series.points.length, points, point)}."}
	 */
	public String getScatterCombination() {
		return getAttr(Attrs.scatterCombination, "{series.name}, series {seriesNumber} of {chart.series.length}, scatter plot with {series.points.length} {#plural(series.points.length, points, point)}.").asString();
	}

	public void setScatterCombination(String scatterCombination) {
		setAttr(Attrs.scatterCombination, scatterCombination);
	}

	/**
	 * <p>Default: {@code "{series.name}, line {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}."}
	 */
	public String getSpline() {
		return getAttr(Attrs.spline, "{series.name}, line {seriesNumber} of {chart.series.length} with {series.points.length} data {#plural(series.points.length, points, point)}.").asString();
	}

	public void setSpline(String spline) {
		setAttr(Attrs.spline, spline);
	}

	/**
	 * <p>Default: {@code "{series.name}, series {seriesNumber} of {chart.series.length}. Line with {series.points.length} data {#plural(series.points.length, points, point)}."}
	 */
	public String getSplineCombination() {
		return getAttr(Attrs.splineCombination, "{series.name}, series {seriesNumber} of {chart.series.length}. Line with {series.points.length} data {#plural(series.points.length, points, point)}.").asString();
	}

	public void setSplineCombination(String splineCombination) {
		setAttr(Attrs.splineCombination, splineCombination);
	}
}