/* Separator.java

	Purpose:
		
	Description:
		
	History:
		11:59 AM 2022/9/8, Created by jumperchen

Copyright (C) 2022 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import java.util.LinkedHashMap;
import java.util.Map;

import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.chart.util.MapsHelper;
import org.zkoss.lang.Generics;

/**
 * Options object for Breadcrumbs separator.
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 * @author jumperchen
 * @since 10.2.1.0
 */
public class Separator extends Optionable {

	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		text,
		style
	}

	/**
	 * Returns CSS styles for the separator.
	 * <p>Default: null
	 */
	public <K, V> Map<K, V> getStyle() {
		return Generics.cast(getAttr(Attrs.style));
	}

	/**
	 * Sets CSS styles for the separator.
	 * <p>Default: null
	 */
	public void setStyle(String style) {
		setStyle(MapsHelper.parse(new LinkedHashMap<>(), style, ':', ';', '\''));
	}

	/**
	 * Sets CSS styles for the separator.
	 * <p>Default: null
	 */
	public <K, V> void setStyle(Map<K, V> style) {
		setAttr(Attrs.style, style);
	}

	/**
	 * Returns the separator text.
	 * <p>Default: {@code "/"}
	 */
	public String getText() {
		return getAttr(Attrs.text, "/").asString();
	}

	/**
	 * Sets the separator text.
	 * <p>Default: {@code "/"}
	 */
	public void setText(String text) {
		setAttr(Attrs.text, text);
	}
}
