/* PlotOptionsSonification.java

        Purpose:
                
        Description:
                
        History:
                Wed Sep 27 16:55:41 CST 2023, Created by jamson

Copyright (C) 2023 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

import org.zkoss.chart.util.DynamicalAttribute;
import org.zkoss.lang.Generics;

/**
 * Sonification/audio chart options for a series.
 * @author Jamson Chan
 * @since 11.2.0.0
 */
public class SeriesSonification extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		contextTracks,
		defaultInstrumentOptions,
		defaultSpeechOptions,
		enabled,
		pointGrouping,
		tracks
	}

	/**
	 * Returns context tracks for this series. Context tracks are tracks that are not tied to data points.
	 * <p>Given as an array of instrument tracks, speech tracks, or a mix of both.
	 */
	public List<ContextTracks> getContextTracks() {
		List<ContextTracks> contextTracks = (List<ContextTracks>) getAttr(Attrs.contextTracks);
		if (contextTracks == null) {
			contextTracks = new ArrayList<ContextTracks>();
			setContextTracks(contextTracks);
		}
		return contextTracks;
	}

	/**
	 * Sets context tracks for this series. Context tracks are tracks that are not tied to data points.
	 * <p>Given as an array of instrument tracks, speech tracks, or a mix of both.
	 */
	public void setContextTracks(List<ContextTracks> contextTracks) {
		setAttr(Attrs.contextTracks, contextTracks);
	}

	/**
	 * Returns default options for all this series' instrument tracks.
	 */
	public DefaultInstrumentOptions getDefaultInstrumentOptions() {
		DefaultInstrumentOptions defaultInstrumentOptions = (DefaultInstrumentOptions) getAttr(Attrs.defaultInstrumentOptions);
		if (defaultInstrumentOptions == null) {
			defaultInstrumentOptions = new DefaultInstrumentOptions();
			setDefaultInstrumentOptions(defaultInstrumentOptions);
		}
		return defaultInstrumentOptions;
	}

	/**
	 * Sets default options for all this series' instrument tracks.
	 */
	public void setDefaultInstrumentOptions(DefaultInstrumentOptions defaultInstrumentOptions) {
		setAttr(Attrs.defaultInstrumentOptions, defaultInstrumentOptions);
	}

	/**
	 * Returns default options for all this series' speech tracks.
	 */
	public DefaultSpeechOptions getDefaultSpeechOptions() {
		DefaultSpeechOptions defaultSpeechOptions = (DefaultSpeechOptions) getAttr(Attrs.defaultSpeechOptions);
		if (defaultSpeechOptions == null) {
			defaultSpeechOptions = new DefaultSpeechOptions();
			setDefaultSpeechOptions(defaultSpeechOptions);
		}
		return defaultSpeechOptions;
	}

	/**
	 * Sets default options for all this series' speech tracks.
	 */
	public void setDefaultSpeechOptions(DefaultSpeechOptions defaultSpeechOptions) {
		setAttr(Attrs.defaultSpeechOptions, defaultSpeechOptions);
	}

	/**
	 * Returns whether or not sonification is enabled for this series.
	 * <p>Default: {@code true}
	 */
	public boolean isEnabled() {
		return getAttr(Attrs.enabled, true).asBoolean();
	}

	/**
	 * Sets whether or not sonification is enabled for this series.
	 */
	public void setEnabled(Boolean enabled) {
		setAttr(Attrs.enabled, enabled, true);
	}

	/**
	 * Returns sonification point grouping options for this series.
	 */
	public PointGrouping getPointGrouping() {
		PointGrouping pointGrouping = (PointGrouping) getAttr(Attrs.pointGrouping);
		if (pointGrouping == null) {
			pointGrouping = new PointGrouping();
			setPointGrouping(pointGrouping);
		}
		return pointGrouping;
	}

	/**
	 * Sets sonification point grouping options for this series.
	 */
	public void setPointGrouping(PointGrouping pointGrouping) {
		setAttr(Attrs.pointGrouping, pointGrouping);
	}

	/**
	 * Returns the size of tracks.
	 */
	public int getTracksSize() {
		List<Series> list = Generics.cast(getAttr(Attrs.tracks));
		return list == null ? 0 : list.size();
	}

	/**
	 * Returns the Track options, if any, Otherwise, create a new one.
	 * <p>
	 * Returns the first node (index 0) by default.
	 * <p>Tracks for this series.
	 * <p>Given as an array of instrument tracks, speech tracks, or a mix of both.
	 */
	public Track getTracks() {
		return getTracks(0);
	}

	/**
	 * Returns the Track options from given index, if any, Otherwise,
	 * create a new one.
	 * <p>Tracks for this series.
	 * <p>Given as an array of instrument tracks, speech tracks, or a mix of both.
	 */
	public Track getTracks(int index) {
		List<Track> list = Generics.cast(getAttr(Attrs.tracks));
		if (list == null) {
			list = new LinkedList<Track>();
			setAttr(Attrs.tracks, list);
		}

		int size = list.size();
		if (size <= index) {
			for (int i = index - size + 1; i > 0; i--) {
				list.add(new Track());
			}
		}
		return list.get(index);
	}
}
