package org.zkoss.chart.model;

import java.util.Collection;

/**
 * A data model to be used with box plot.
 * @author Christopher
 *
 */
public interface BoxPlotModel extends ChartsModel {
	/**
	 * Get a series of the specified index;
	 */
	public Comparable<?> getSeries(int index);
	
	/**
	 * Get all series as a collection.
	 */
	public Collection<Comparable<?>> getSeries();
	
	/**
	 * Get data count of a specified series.
	 * @param series the specified series.
	 */
	public int getDataCount(Comparable<?> series);
	/**
	 * Get the name value from the specified series at the given index.
	 * @param series
	 * @param index
	 * @return name the name value
	 */
	public String getName(Comparable<?> series, int index);
	/**
	 * Get the x value from the specified series at the given index.
	 * @param series
	 * @param index
	 * @return x the x value
	 */
	public Number getX(Comparable<?> series, int index);
	/**
	 * Get the low value from the specified series at the given index.
	 * @param series
	 * @param index
	 * @return low the low value
	 */
	public Number getLow(Comparable<?> series, int index);
	/**
	 * Get the q1 value from the specified series at the given index.
	 * @param series
	 * @param index
	 * @return q1 the q1 value
	 */
	public Number getQ1(Comparable<?> series, int index);
	/**
	 * Get the median value from the specified series at the given index.
	 * @param series
	 * @param index
	 * @return median the median value
	 */
	public Number getMedian(Comparable<?> series, int index);
	/**
	 * Get the q3 value from the specified series at the given index.
	 * @param series
	 * @param index
	 * @return q3 the q3 value
	 */
	public Number getQ3(Comparable<?> series, int index);
	/**
	 * Get the high value from the specified series at the given index.
	 * @param series
	 * @param index
	 * @return high the high value
	 */
	public Number getHigh(Comparable<?> series, int index);
	
	/**
	 * Replace the (low, q1, median, q3, high) value at the given index of the specified series.
	 * @param series the series
	 * @param low the low value
	 * @param q1 the q1 value
	 * @param median the median value
	 * @param q3 the q1 value
	 * @param high the high value
	
	 * @param index the data index
	 */
	public void setValue(Comparable<?> series, Number low, Number q1, Number median, Number q3, Number high, int index);
	/**
	 * Replace the (x, low, q1, median, q3, high) value at the given index of the specified series.
	 * @param series the series
	 * @param x the x value
	 * @param low the low value
	 * @param q1 the q1 value
	 * @param median the median value
	 * @param q3 the q1 value
	 * @param high the high value
	
	 * @param index the data index
	 */
	public void setValue(Comparable<?> series, Number x, Number low, Number q1, Number median, Number q3, Number high, int index);
	/**
	 * Replace the (name, low, q1, median, q3, high) value at the given index of the specified series.
	 * @param series the series
	 * @param low the low value
	 * @param q1 the q1 value
	 * @param median the median value
	 * @param q3 the q1 value
	 * @param high the high value
	
	 * @param index the data index
	 */
	public void setValue(Comparable<?> series, String name, Number low, Number q1, Number median, Number q3, Number high, int index);
	
	/**
	 * Append a (low, q1, median, q3, high) value into the the given series.
	 * @param series the series to append this value into
	 * @param low the low value
	 * @param q1 the q1 value
	 * @param median the median value
	 * @param q3 the q1 value
	 * @param high the high value
	 */
	public void addValue(Comparable<?> series, Number low, Number q1, Number median, Number q3, Number high);
	/**
	 * Append a (x, low, q1, median, q3, high) value into the the given series.
	 * @param series the series to append this value into
	 * @param x the x value
	 * @param low the low value
	 * @param q1 the q1 value
	 * @param median the median value
	 * @param q3 the q1 value
	 * @param high the high value
	 */
	public void addValue(Comparable<?> series, Number x, Number low, Number q1, Number median, Number q3, Number high);
	/**
	 * Append a (name, low, q1, median, q3, high) value into the the given series.
	 * @param series the series to append this value into
	 * @param name the name value
	 * @param low the low value
	 * @param q1 the q1 value
	 * @param median the median value
	 * @param q3 the q1 value
	 * @param high the high value
	 */
	public void addValue(Comparable<?> series, String name, Number low, Number q1, Number median, Number q3, Number high);
	/**
	 * Add a (low, q1, median, q3, high) value into the the given series at the given index.
	 * @param series the series to append this value into
	 * @param low the low value
	 * @param q1 the q1 value
	 * @param median the median value
	 * @param q3 the q1 value
	 * @param high the high value
	 * @param index the index value
	 */
	public void addValue(Comparable<?> series, Number low, Number q1, Number median, Number q3, Number high, int index);
	/**
	 * Add a (x, low, q1, median, q3, high) value into the the given series at the given index.
	 * @param series the series to append this value into
	 * @param x the x value
	 * @param low the low value
	 * @param q1 the q1 value
	 * @param median the median value
	 * @param q3 the q1 value
	 * @param high the high value
	 * @param index the index value
	 */
	public void addValue(Comparable<?> series, Number x, Number low, Number q1, Number median, Number q3, Number high, int index);
	/**
	 * Add a (name, low, q1, median, q3, high) value into the the given series at the given index.
	 * @param series the series to append this value into
	 * @param name the name value
	 * @param low the low value
	 * @param q1 the q1 value
	 * @param median the median value
	 * @param q3 the q1 value
	 * @param high the high value
	 * @param index the index value
	 */
	public void addValue(Comparable<?> series, String name, Number low, Number q1, Number median, Number q3, Number high, int index);
	
	/**
	 * Remove data of a specified series.
	 * @param series the series
	 */
	public void removeSeries(Comparable<?> series);

	/**
	 * Remove a (x, low, q1, median, q3, high) value from the specified series at the given index.
	 * @param series the series.
	 * @param index the data index.
	 */	
	public void removeValue(Comparable<?> series, int index);

	/**
	 * clear this model.
	 */	
	public void clear();
}
