/* DependencyWheelPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Fri Nov 29 15:26:06 CST 2019, Created by rudyhuang

Copyright (C) 2019 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for dependency wheel plot
 *
 * @author rudyhuang
 * @since 7.2.1.0
 */
public class DependencyWheelPlotOptions extends SankeyPlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		borderWidth, size, startAngle
	}

	/**
	 * Returns the width of the border surrounding each column or bar.
	 * <p>
	 * Default: {@code 0} when the columns are so dense that a border would cover the next column.
	 * @since 10.2.1.0
	 */
	public Number getBorderWidth() {
		return getAttr(Attrs.borderWidth, 0).asNumber();
	}

	/**
	 * Sets the width of the border surrounding each column or bar.
	 * @since 10.2.1.0
	 */
	public void setBorderWidth(Number borderWidth) {
		setAttr(Attrs.borderWidth, borderWidth);
	}

	/**
	 * Returns the size of the wheel in pixel or percent relative to the canvas space.
	 *
	 * <p>
	 * Defaults to {@code "100%"}.
	 * @since 10.2.1.0
	 */
	public Object getSize() {
		return getAttr(Attrs.size, "100%").asValue();
	}

	/**
	 * Sets the size of the wheel in pixel or percent relative to the canvas space.
	 *
	 * <p>
	 * Defaults to {@code "100%"}.
	 * @since 10.2.1.0
	 */
	public void setSize(String size) {
		setAttr(Attrs.size, size);
	}

	/**
	 * Sets the size of the wheel in pixel or percent relative to the canvas space.
	 *
	 * <p>
	 * Defaults to {@code "100%"}.
	 * @since 10.2.1.0
	 */
	public void setSize(Number size) {
		setAttr(Attrs.size, size);
	}

	/**
	 * Returns the start angle of the dependency wheel in degrees where 0 is top and
	 * 90 right.
	 * <p> Default: 0
	 * @since 10.2.1.0
	 */
	public Number getStartAngle() {
		return getAttr(Attrs.startAngle, 0).asNumber();
	}

	/**
	 * Sets the start angle of the dependency wheel in degrees where 0 is top and 90
	 * right.
	 * @since 10.2.1.0
	 */
	public void setStartAngle(Number startAngle) {
		setAttr(Attrs.startAngle, startAngle, 0);
	}
}
