/* FunnelPlotOptions.java

	Purpose:
		
	Description:
		
	History:
		Thu, Jan 16, 2014  3:58:30 PM, Created by RaymondChao

Copyright (C) 2014 Potix Corporation. All Rights Reserved.

 */
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * An option for funnel plot
 * <p>
 * All the options in this class support {@link DynamicalAttribute}.
 * 
 * @author jumperchen
 * @author RaymondChao
 */
public class FunnelPlotOptions extends PiePlotOptions {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		borderRadius, height, neckHeight, neckWidth, width, reversed
	}

	/**
	 * Returns the corner radius of the border surrounding all points or series. A number signifies pixels.
	 * A percentage string, like for example 50%, signifies a size relative to the series width.
	 * <p>Default: {@code 0}
	 * @since 11.2.0.0
	 */
	public Object getBorderRadius() {
		return getAttr(Attrs.borderRadius, 0).asValue();
	}

	@Override
	protected DataLabels newDataLabels() {
		return new FunnelDataLabels();
	}

	@Override
	public FunnelDataLabels getDataLabels() {
		return (FunnelDataLabels) super.getDataLabels();
	}

	/**
	 * Returns the height of the neck, the lower part of a funnel. If it is a
	 * number it defines the pixel height, if it is a percentage string it is
	 * the percentage of the plot area height.
	 * <p>
	 * Default: 100%
	 */
	public String getHeight() {
		return getAttr(Attrs.height, "100%").asString();
	}

	/**
	 * Sets the height of the neck, the lower part of a funnel. If it is a
	 * number it defines the pixel height, if it is a percentage string it is
	 * the percentage of the plot area height.
	 */
	public void setHeight(String height) {
		setAttr(Attrs.height, height, "100%");
	}

	/**
	 * Returns the height of the neck, the lower part of the funnel. A number
	 * defines pixel width, a percentage string defines a percentage of the plot
	 * area height.
	 * <p> Default: 25%
	 */
	public String getNeckHeight() {
		return getAttr(Attrs.neckHeight, "25%").asString();
	}

	/**
	 * Sets the height of the neck, the lower part of the funnel. A number
	 * defines pixel width, a percentage string defines a percentage of the plot
	 * area height.
	 */
	public void setNeckHeight(String neckHeight) {
		setAttr(Attrs.neckHeight, neckHeight);
	}

	/**
	 * Returns the width of the neck, the lower part of the funnel. A number
	 * defines pixel width, a percentage string defines a percentage of the plot
	 * area width.
	 * <p> Default: 30%
	 */
	public String getNeckWidth() {
		return getAttr(Attrs.neckWidth, "30%").asString();
	}

	/**
	 * Sets the width of the neck, the lower part of the funnel. A number
	 * defines pixel width, a percentage string defines a percentage of the plot
	 * area width.
	 */
	public void setNeckWidth(String neckWidth) {
		setAttr(Attrs.neckWidth, neckWidth);
	}

	/**
	 * Returns the width of the funnel compared to the width of the plot area,
	 * or the pixel width if it is a number.
	 * <p> Default: 90%
	 */
	public String getWidth() {
		return getAttr(Attrs.width, "90%").asString();
	}

	/**
	 * Sets the width of the funnel compared to the width of the plot area, or
	 * the pixel width if it is a number.
	 */
	public void setWidth(String width) {
		setAttr(Attrs.width, width, "90%");
	}

	/**
	 * Returns whether the series should be placed on the other side of the plotArea.
	 *
	 * <p>
	 * Default: {@code false}.
	 * @since 10.2.1.0
	 */
	public boolean isReversed() {
		return getAttr(Attrs.reversed, false).asBoolean();
	}

	/**
	 * Sets whether the series should be placed on the other side of the plotArea.
	 * @since 10.2.1.0
	 */
	public void setReversed(boolean reversed) {
		setAttr(Attrs.reversed, reversed);
	}

}