/* TreeGraphLink.java

	Purpose:
		
	Description:
		
	History:
		11:13 AM 2023/4/7, Created by jumperchen

Copyright (C) 2023 Potix Corporation. All Rights Reserved.
*/
package org.zkoss.chart.plotOptions;

import org.zkoss.chart.Marker;
import org.zkoss.chart.Optionable;
import org.zkoss.chart.PlotAttribute;
import org.zkoss.chart.util.DynamicalAttribute;

/**
 * Link style options.
 *
 * @author jumperchen
 * @since 10.3.3.0
 */
public class TreeGraphLink extends Optionable {
	private enum Attrs implements PlotAttribute, DynamicalAttribute {
		color, cursor, lineWidth, radius, type
	}

	/**
	 * Returns the color of the link between two nodes.
	 * <p>
	 * Default: #666666
	 */
	public String getColor() {
		return getAttr(Attrs.color, "#666666").asString();
	}

	/**
	 * Sets the color of the link between two nodes.
	 */
	public void setColor(String color) {
		setAttr(Attrs.color, color);
	}

	/**
	 * Returns the mouse cursor.
	 * <p>
	 * Default: "default"
	 */
	public String getCursor() {
		return getAttr(Attrs.cursor, null).asString();
	}

	/**
	 * Sets the mouse cursor.
	 * <p>
	 * Default: "default"
	 */
	public void setCursor(String cursor) {
		setAttr(Attrs.cursor, cursor);
	}

	/**
	 * Returns pixel width of the graph line.
	 * <p>
	 * Default: 1.
	 */
	public Number getLineWidth() {
		return getAttr(Attrs.lineWidth, 1).asNumber();
	}

	/**
	 * Sets pixel width of the graph line.
	 */
	public void setLineWidth(Number lineWidth) {
		setAttr(Attrs.lineWidth, lineWidth, 1);
	}

	/**
	 * Returns radius for the rounded corners of the links between nodes.
	 * Works for "default" link type.
	 * <p>
	 * Default: 10
	 */
	public Number getRadius() {
		return getAttr(Attrs.radius, 10).asNumber();
	}

	/**
	 * Sets radius for the rounded corners of the links between nodes.
	 * Works for "default" link type.
	 * <p>
	 * Default: 10
	 */
	public void setRadius(Number radius) {
		setAttr(Attrs.radius, radius, 10);
	}

	/**
	 * Returns the type of the link shape
	 * <p>
	 * Default: "curved"
	 */
	public String getType() {
		return getAttr(Attrs.type, "curved").asString();
	}

	/**
	 * Sets the type of the link shape in "default", "curved", and "straight".
	 * <p>
	 * Default: "curved"
	 */
	public void setType(String type) {
		setAttr(Attrs.type, type);
	}
}
